@@ -114,3 +114,17 @@ class DelimitEndpoints:
         response = self.base_class.delete_data(uri="PowersAttorneyDel", filter=data_filter)
         response.raise_for_status()
         return response
+
+
+    def delimit_absence(self, employee_id, start_date, end_date):
+        """
+        Delimit absence record in SAP
+        :param employee_id: the AFAS ID of the employee in case
+        :param start_date: the start date of the record you want to delimit
+        :param end_date: the end date at which the record will be delimit
+        :return: status
+        """
+        data_filter = f"Afasemployeenumber='{employee_id}',Startdate='{start_date}',Enddate='{end_date}'"
+        response = self.base_class.delete_data(uri="AbsenceDel", filter=data_filter)
+        response.raise_for_status()
+        return response
\ No newline at end of file
