@@ -40,6 +40,6 @@ class GetEndpoints:
                 df.reset_index(drop=True, inplace=True)
             except Exception as e:
                 print(f"Error in batch {i}: {e}")
-            counter += 10
+            counter += batch_size
             print(f'Processed {counter} records from {len(id_list)}')
         return df
