@@ -203,7 +203,7 @@ class PostEndpoints:
             "Enddate": data['end_date'],
             "Shorttext": data['job_code'],
             "Longtext": data['job'],
-            "Omleader": False if data['is_manager'] is None or data['is_manager'] == '' else True,
+            "Omleader": False if data['is_manager'] is None or data['is_manager'] == '' else data['is_manager'],
             "OrgunitIDassigend": data['sap_organisational_unit_id']
         }
 
